function [button time] = cedrusxid

s1 = serial('COM2', 'BaudRate', 115200,'DataBits', 8, 'StopBits', 1, 'FlowControl', 'none', 'Parity', 'none', 'Terminator', 'CR', 'Timeout', 400, 'InputBufferSize', 16000);

fopen(s1);

% % Sets the device protocol to XID mode
% % Note: char(13) sends the Carriage Return terminator
% 
% fprintf(s1,['c10',char(13)]);
% 
% % Debug information from http://www.cedrus.com/xid/properties.htm
% %
% % Note: 0 is ASCII value 48, 1 is ASCII value 49, and so forth.
% 
% fprintf(s1,['_d3',char(13)]);
% fread(s1,1)
% fprintf(s1,['_d1',char(13)]);
% fscanf(s1)

% Sets the device protocol to XID mode
% Note: char(13) sends the Carriage Return terminator

fprintf(s1,['c10',char(13)]);

% XID devices send six bytes of information in the following format:
% <k><key info><RT>:
%
% The first parameter is simply the letter k, lower case 
% 
% The second parameter consists of one byte, divided into the following
% bits
% 
% Bits 0-3 store the port number. For Lumina LP-400, the push buttons and
% scanner trigger are on port 0; the RJ45 I/O lines are on port 1.
% For SV?1, voice key is on port 2 and the RJ45 is on port 1  there is
% no port 0. For the RB-x30 response pads, the push buttons are on port 0
% and the RJ45 port is on port 1.
% 
% Bit 4 stores an action flag. If set, the button has been pressed. If
% cleared, the button has been released.
% 
% Bits 5-7 indicate which push button was pressed.
% 
% The reaction time consists of four bytes and is the time elapsed since
% the Reaction Time timer was last reset. See description of command "e5".
%
% Information taken from http://www.cedrus.com/xid/protocols.htm

response = fread(s1,6);

% Extracts byte 2 to determine which button was pushed

button = (response(2));

% Extracts bytes 3-6 and is the time elapsed in milliseconds since the
% Reaction Time timer was last reset
%
% For more information about the use of XID timers refer to
% http://www.cedrus.com/xid/timing.htm

time = (response(3)+(response(4)*256)+(response(5)*65536)+(response(6)*(65536*256)));

fclose(s1);